import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;

/**
 * The class <code> Converter </code> reads the file and creates converted file.
 * @author Viatcheslav Korenwein
 * @version 1.0
 */
public final class Converter {
	
	/**
	 * Checks if the file has suitable format and convert if needed
	 * @param file
	 * @return converted file
	 */
	public static File convertFile(File file) throws WrongFileFormatException {
	
		// if file is not yet converted
		if (file.getName().length() < 10 || ! file.getName().substring(file.getName().length() - 9).equals(".conv.txt")) {
			String nameForNewFile = "dataset/converted/" + file.getName().replaceFirst("[.][^.]+$", "") + ".conv.txt";			
			File convertedFile = new File(nameForNewFile);
			// directory
			File dir = convertedFile.getParentFile();
			// if directory does not exist create it
			if (! dir.exists())
				dir.mkdirs();
			try {
				// if converted file not exist then create and convert
				if (convertedFile.createNewFile()) {					
					try {
						Converter.convert(file, convertedFile);
						return convertedFile;
					} catch (WrongFileFormatException wff) {
						convertedFile.delete();
						throw new WrongFileFormatException(wff.getMessage());
					}
					
				}
				// if converted file is already exist work with it
				else
					return convertedFile;
			} catch (IOException ioe) {
				System.err.println(ioe.getMessage());
			} 
		}
		return file;
	}

	/**
	 * Converts file: deletes lines beginning with # and deletes loops
	 * @param inputFile
	 * @param outputFile
	 * @return true if output file is created and false otherwise
	 */
	public static boolean convert(File inputFile, File outputFile) throws WrongFileFormatException {
		
		boolean created = true;

		try {		
			// reader and writer
			FileReader fr = new FileReader(inputFile);
			BufferedReader reader = new BufferedReader(fr);		
			FileWriter fw = new FileWriter(outputFile);
			BufferedWriter writer = new BufferedWriter(fw);

			// useful variables			
			int token;			  // current token
			
			int linenumber = 0;
			String from, to;			

			while( (token=reader.read()) != -1 ){    // while a token can be read out do
				String charLine = ((char)token + reader.readLine()); //read the whole line
				
				// ignore lines begin with #
				if (charLine.startsWith("#")){
					continue;
				}

				linenumber++;
				
				// find tabulator 
				int index = charLine.indexOf("\t");
				if (index == -1){					
					reader.close();
					writer.close();
					throw new WrongFileFormatException("Wrong file format. Error in line " + linenumber + ".");
				}
				
				// read "from"
				try{
					from = charLine.substring(0, index);
				}
				catch(IllegalArgumentException e){					
					reader.close();
					writer.close();
					throw new WrongFileFormatException("Wrong file format. Error in line " + linenumber + ".");
				}
				
				// read "to"
				try{	
					to = charLine.substring(index + 1, charLine.length());
				}
				catch(IllegalArgumentException e){					
					reader.close();
					writer.close();
					throw new WrongFileFormatException("Wrong file format. Error in line " + linenumber + ".");
				}
				
				// ignore loops
				if (from.equals(to)){
					continue;
				}
				
				writer.write(charLine + "\n");
			}
			
			reader.close();
			writer.close();

		} catch (FileNotFoundException e) {			
			System.err.println("file not found...");
		} catch (IOException e) {
			e.printStackTrace();
		}	
		
		return created;
	}
}