import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
//import java.io.IOException;
import java.io.Reader;
import java.util.Map;

import org.jgrapht.Graph;
import org.jgrapht.UndirectedGraph;
import org.jgrapht.ext.CSVFormat;
import org.jgrapht.ext.CSVImporter;
import org.jgrapht.ext.EdgeProvider;
import org.jgrapht.ext.ImportException;
import org.jgrapht.ext.VertexProvider;
import org.jgrapht.graph.DefaultEdge;
import org.jgrapht.graph.SimpleGraph;

/**
 * The class <code> FileToGraph </code> creates an undirected graph from a given file.
 * @author Viatcheslav Korenwein
 * @version 1.0
 */
public class FileToGraph {

	/**
	 * Checks if the file has suitable format, convert if needed and creates an undirected graph.
	 * @param file
	 * @return graph
	 */
	public static UndirectedGraph<String, DefaultEdge> fileToGraph(File file){

		// declaration
		UndirectedGraph<String, DefaultEdge> graph = new SimpleGraph<>(DefaultEdge.class);

		// read graph		
		try {
			Reader fileReader;
			fileReader = new FileReader(file);
			CSVImporter<String, DefaultEdge> importer = createImporter(graph, CSVFormat.EDGE_LIST, '\t');
			importer.importGraph(graph, fileReader);
		} catch (FileNotFoundException fnfe) {
			System.err.println(fnfe.getMessage());
		}
		catch(ImportException ie){
			System.err.println(ie.getMessage());
		}
		
		return graph;
	}

	/*
	 * method is copied from CSVImporterTest
	 */
	private static <E> CSVImporter<String, E> createImporter(
			Graph<String, E> g, CSVFormat format, Character delimiter)
			{
		VertexProvider<String> vp = new VertexProvider<String>()
				{
			@Override
			public String buildVertex(String label, Map<String, String> attributes)
			{
				return label;
			}
				};

				EdgeProvider<String, E> ep = new EdgeProvider<String, E>()
						{

					@Override
					public E buildEdge(String from, String to, String label, Map<String, String> attributes)
					{
						return g.getEdgeFactory().createEdge(from, to);
					}

						};

						CSVImporter<String, E> importer = new CSVImporter<>(vp, ep, format, delimiter);

						return importer;
			}
}