package blossom5_JNI;

import java.util.HashSet;
import java.util.Set;

import org.jgrapht.Graph;
import org.jgrapht.UndirectedGraph;
import org.jgrapht.alg.interfaces.MatchingAlgorithm;
import org.jgrapht.graph.DefaultEdge;
import org.jgrapht.util.TypeUtil;

import Blossom5matching;

public class Blossom5<V, E> implements MatchingAlgorithm<V, E>{

    private final UndirectedGraph<V, E> graph;
    
    /**
     * Construct an instance of the Blossom5 algorithm.
     * @param graph the input graph
     * @throws IllegalArgumentException if the graph is not undirected
     */
    public Blossom5(Graph<V, E> graph)
    {
        if (graph == null) {
            throw new IllegalArgumentException("Input graph cannot be null");
        }
        if (!(graph instanceof UndirectedGraph)) {
            throw new IllegalArgumentException("Only undirected graphs supported");
        }
        this.graph = TypeUtil.uncheckedCast(graph, null);
    }
    
	@Override
	public Matching<E> computeMatching() {
		
		int vertexNumber = graph.vertexSet().size();
		int edgeNumber = graph.edgeSet().size();
		int[] edges = new int[edgeNumber*2];
		DefaultEdge[] edgesEquivalence = new DefaultEdge[edgeNumber];
		int i = 0;
		for (E edge : graph.edgeSet()) {
			edges[i*2] = Integer.parseInt((String) graph.getEdgeSource(edge));
			edges[i*2 + 1] = Integer.parseInt((String) graph.getEdgeTarget(edge));
			edgesEquivalence[i] = (DefaultEdge) edge;
			i++;
		}
		int[] maxm = Blossom5matching.getMaximumMatching(vertexNumber, edgeNumber, edges);
		
		// make matching instance for return
		Set<E> matchedEdges = new HashSet<E>();
		for (int j = 0; j < maxm.length; j++) {
			matchedEdges.add((E) edgesEquivalence[maxm[j]]);
		}
		
		return new MatchingImpl<>(matchedEdges, matchedEdges.size());
	}

}
