package kernelization;

import org.jgrapht.alg.interfaces.MatchingAlgorithm.Matching;

/**
 * The class <code> MatchingAndComputationTimes </code> for objects that contain matching and computation times of DRR, matching and postprocessing.
 * @author Viatcheslav Korenwein
 * @version 1.0
 */
public class MatchingAndComputationTimes<E> {

	/**
	 * the matching we are working on
	 */
	private Matching<E> matching;

	/**
	 * calculation time of data reduction rules
	 */
	private double timeForDRR;

	/**
	 * calculation time of matching calculation of kernel
	 */    
	private double timeForMatching;

	/**
	 * calculation time of adding edges to matching of kernel to get matching of input graph
	 */    
	private double timeForPostprocessing;    

	/**
	 * Constructs an object using a matching and calculation times of DRR, matching and postprocessing.
	 * @param matching - a matching
	 * @param timeForDRR - calculation time of data reduction rules
	 * @param timeForMatching - calculation time of matching calculation of kernel
	 * @param timeForPostprocessing - calculation time of adding edges to matching of kernel to get matching of input graph
	 */
	public MatchingAndComputationTimes(Matching<E> matching, double timeForDRR, double timeForMatching, double timeForPostprocessing) {
		this.matching = matching;
		this.timeForDRR = timeForDRR;
		this.timeForMatching = timeForMatching;
		this.timeForPostprocessing = timeForPostprocessing;
	}

	/**
	 * @return the matching
	 */
	public Matching<E> getMatching() {
		return matching;
	}

	/**
	 * @return the timeForDRR
	 */
	public double getTimeForDRR() {
		return timeForDRR;
	}

	/**
	 * @return the timeForMatching
	 */
	public double getTimeForMatching() {
		return timeForMatching;
	}

	/**
	 * @return the timeForPostprocessing
	 */
	public double getTimeForPostprocessing() {
		return timeForPostprocessing;
	}

	/**
	 * @param matching the matching to set
	 */
	public void setMatching(Matching<E> matching) {
		this.matching = matching;
	}

	/**
	 * @param timeForDRR the timeForDRR to set
	 */
	public void setTimeForDRR(double timeForDRR) {
		this.timeForDRR = timeForDRR;
	}

	/**
	 * @param timeForMatching the timeForMatching to set
	 */
	public void setTimeForMatching(double timeForMatching) {
		this.timeForMatching = timeForMatching;
	}

	/**
	 * @param timeForPostprocessing the timeForPostprocessing to set
	 */
	public void setTimeForPostprocessing(double timeForPostprocessing) {
		this.timeForPostprocessing = timeForPostprocessing;
	}
	
}
